package com.jz.dmp.modules.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.bean.DmpOptLogBatch;
import com.jz.dmp.modules.controller.bean.DmpOptLogDto;
import com.jz.dmp.modules.controller.bean.DmpOptLogRequest;
import com.jz.dmp.modules.dao.DmpOptLogMapper;
import com.jz.dmp.modules.model.DmpOptLog;
import com.jz.dmp.modules.service.DmpOptLogService;

/**
 * 操作日志表服务的实现?
 * 
 * @author ybz
 *
 */
@Service("dmpOptLogService")
public class DmpOptLogServiceImpl extends BaseService implements DmpOptLogService {

	private static Logger logger = LoggerFactory.getLogger(DmpOptLogServiceImpl.class);

	@Autowired
	private DmpOptLogMapper dmpOptLogMapper;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#findListWithPage(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpOptLogDto> findListWithPage(DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpOptLogDto> pageInfoResponse = new PageInfoResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpOptLogRequest.getOptId() != null) {
			param.put("optId", dmpOptLogRequest.getOptId());
		}
		//操作人ID
		if (dmpOptLogRequest.getUserId() != null) {
			param.put("userId", dmpOptLogRequest.getUserId());
		}
		//操作人姓名
		if (!StringUtils.isEmpty(dmpOptLogRequest.getUserName())) {
			param.put("userName", dmpOptLogRequest.getUserName());
		}
		//操作时间起
		if (dmpOptLogRequest.getOptTimeStart() != null) {
			param.put("optTimeStart", dmpOptLogRequest.getOptTimeStart());
		}
		//操作时间止
		if (dmpOptLogRequest.getOptTimeEnd() != null) {
			param.put("optTimeEnd", dmpOptLogRequest.getOptTimeEnd());
		}
		//操作功能模块
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptModular())) {
			param.put("optModular", dmpOptLogRequest.getOptModular());
		}
		//操作类型
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptType())) {
			param.put("optType", dmpOptLogRequest.getOptType());
		}
		//操作描述
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptDesc())) {
			param.put("optDesc", dmpOptLogRequest.getOptDesc());
		}
		//操作方法
		if (!StringUtils.isEmpty(dmpOptLogRequest.getMethod())) {
			param.put("method", dmpOptLogRequest.getMethod());
		}
		//请求参数
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRequestParam())) {
			param.put("requestParam", dmpOptLogRequest.getRequestParam());
		}
		//操作结果
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptResult())) {
			param.put("optResult", dmpOptLogRequest.getOptResult());
		}
		//IP地址
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptIp())) {
			param.put("optIp", dmpOptLogRequest.getOptIp());
		}
		//备注
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRemark())) {
			param.put("remark", dmpOptLogRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpOptLogRequest.getDataStatus())) {
			param.put("dataStatus", dmpOptLogRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpOptLogRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpOptLogRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpOptLogRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpOptLogRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpOptLogRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpOptLogRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpOptLogRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpOptLogRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpOptLogRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpOptLogRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpOptLogRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpOptLogRequest.getUpdateTimeEnd());
		}
		
		//加上可用标识（未软删除）
		param.put("dataStatu", "1");

		String obderByStr = dmpOptLogRequest.takeOrderByStr(DmpOptLogRequest.class);
        Page page = null;
        if (obderByStr==null) {
        	page = PageHelper.startPage(dmpOptLogRequest.getPageNum(), dmpOptLogRequest.getPageSize());
		} else {
			page = PageHelper.startPage(dmpOptLogRequest.getPageNum(), dmpOptLogRequest.getPageSize(), obderByStr);
		}
		List<DmpOptLogDto> list = dmpOptLogMapper.findList(param);
		PageInfo<DmpOptLogDto> pageInfo = new PageInfo<>(list);

		pageInfoResponse.setCode(StatuConstant.SUCCESS_CODE);
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#findList(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpOptLogDto> findList(DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpOptLogDto> baseBeanResponse = new BaseBeanResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpOptLogRequest.getOptId() != null) {
			param.put("optId", dmpOptLogRequest.getOptId());
		}
		//操作人ID
		if (dmpOptLogRequest.getUserId() != null) {
			param.put("userId", dmpOptLogRequest.getUserId());
		}
		//操作人姓名
		if (!StringUtils.isEmpty(dmpOptLogRequest.getUserName())) {
			param.put("userName", dmpOptLogRequest.getUserName());
		}
		//操作时间起
		if (dmpOptLogRequest.getOptTimeStart() != null) {
			param.put("optTimeStart", dmpOptLogRequest.getOptTimeStart());
		}
		//操作时间止
		if (dmpOptLogRequest.getOptTimeEnd() != null) {
			param.put("optTimeEnd", dmpOptLogRequest.getOptTimeEnd());
		}
		//操作功能模块
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptModular())) {
			param.put("optModular", dmpOptLogRequest.getOptModular());
		}
		//操作类型
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptType())) {
			param.put("optType", dmpOptLogRequest.getOptType());
		}
		//操作描述
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptDesc())) {
			param.put("optDesc", dmpOptLogRequest.getOptDesc());
		}
		//操作方法
		if (!StringUtils.isEmpty(dmpOptLogRequest.getMethod())) {
			param.put("method", dmpOptLogRequest.getMethod());
		}
		//请求参数
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRequestParam())) {
			param.put("requestParam", dmpOptLogRequest.getRequestParam());
		}
		//操作结果
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptResult())) {
			param.put("optResult", dmpOptLogRequest.getOptResult());
		}
		//IP地址
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptIp())) {
			param.put("optIp", dmpOptLogRequest.getOptIp());
		}
		//备注
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRemark())) {
			param.put("remark", dmpOptLogRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpOptLogRequest.getDataStatus())) {
			param.put("dataStatus", dmpOptLogRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpOptLogRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpOptLogRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpOptLogRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpOptLogRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpOptLogRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpOptLogRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpOptLogRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpOptLogRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpOptLogRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpOptLogRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpOptLogRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpOptLogRequest.getUpdateTimeEnd());
		}
		
		//加上可用标识（未软删除）
		param.put("dataStatu", "1");

		List<DmpOptLogDto> list = dmpOptLogMapper.findList(param);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setDatas(list);
		return baseBeanResponse;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#add(com.ycxc.vmts.entity.DmpOptLog,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpOptLog> add(DmpOptLog dmpOptLog, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<>();

		/*$*setOptIdCodeReplace*$*/
		// 创建人
		dmpOptLog.setCreateUserId(getHttpRequestUserId(httpRequest));
		// 创建时间
		dmpOptLog.setCreateTime(new Date());

		dmpOptLogMapper.insertSelective(dmpOptLog);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpOptLog);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#edit(com.ycxc.vmts.entity.DmpOptLog,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpOptLog> edit(DmpOptLog dmpOptLog, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<>();

		// 修改人
		dmpOptLog.setUpdateUserId(getHttpRequestUserId(httpRequest));
		// 修改时间
		dmpOptLog.setUpdateTime(new Date());

		dmpOptLogMapper.updateByPrimaryKeySelective(dmpOptLog);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpOptLog);

		return baseBeanResponse;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#addOrEdit(com.ycxc.vmts.entity.DmpOptLog,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpOptLog> addOrEdit(DmpOptLog dmpOptLog, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<>();
		
		Integer optId = dmpOptLog.getOptId();
		
		if (null==optId) {//新增
			// 创建人
			dmpOptLog.setCreateUserId(getHttpRequestUserId(httpRequest));
			// 创建时间
			dmpOptLog.setCreateTime(new Date());

			dmpOptLogMapper.insertSelective(dmpOptLog);

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("新增成功");
			baseBeanResponse.setData(dmpOptLog);
		} else {//修改
			// 修改人
			dmpOptLog.setUpdateUserId(getHttpRequestUserId(httpRequest));
			// 修改时间
			dmpOptLog.setUpdateTime(new Date());

			dmpOptLogMapper.updateByPrimaryKeySelective(dmpOptLog);

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("修改成功");
			baseBeanResponse.setData(dmpOptLog);
		}
		
		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#findById(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpOptLogDto> findById(Integer optId, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpOptLogDto> baseBeanResponse = new BaseBeanResponse<>();

		DmpOptLogDto dmpOptLogDto = dmpOptLogMapper.findById(optId);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpOptLogDto);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#deleteById(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse deleteById(Integer optId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpOptLogMapper.deleteByPrimaryKey(optId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#deleteById(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDeleteById(Integer optId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpOptLogMapper.softDeleteByPrimaryKey(optId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#deleteById(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse delete(DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpOptLogRequest.getOptId() != null) {
			param.put("optId", dmpOptLogRequest.getOptId());
		}
		//操作人ID
		if (dmpOptLogRequest.getUserId() != null) {
			param.put("userId", dmpOptLogRequest.getUserId());
		}
		//操作人姓名
		if (!StringUtils.isEmpty(dmpOptLogRequest.getUserName())) {
			param.put("userName", dmpOptLogRequest.getUserName());
		}
		//操作时间起
		if (dmpOptLogRequest.getOptTimeStart() != null) {
			param.put("optTimeStart", dmpOptLogRequest.getOptTimeStart());
		}
		//操作时间止
		if (dmpOptLogRequest.getOptTimeEnd() != null) {
			param.put("optTimeEnd", dmpOptLogRequest.getOptTimeEnd());
		}
		//操作功能模块
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptModular())) {
			param.put("optModular", dmpOptLogRequest.getOptModular());
		}
		//操作类型
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptType())) {
			param.put("optType", dmpOptLogRequest.getOptType());
		}
		//操作描述
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptDesc())) {
			param.put("optDesc", dmpOptLogRequest.getOptDesc());
		}
		//操作方法
		if (!StringUtils.isEmpty(dmpOptLogRequest.getMethod())) {
			param.put("method", dmpOptLogRequest.getMethod());
		}
		//请求参数
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRequestParam())) {
			param.put("requestParam", dmpOptLogRequest.getRequestParam());
		}
		//操作结果
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptResult())) {
			param.put("optResult", dmpOptLogRequest.getOptResult());
		}
		//IP地址
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptIp())) {
			param.put("optIp", dmpOptLogRequest.getOptIp());
		}
		//备注
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRemark())) {
			param.put("remark", dmpOptLogRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpOptLogRequest.getDataStatus())) {
			param.put("dataStatus", dmpOptLogRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpOptLogRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpOptLogRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpOptLogRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpOptLogRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpOptLogRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpOptLogRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpOptLogRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpOptLogRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpOptLogRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpOptLogRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpOptLogRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpOptLogRequest.getUpdateTimeEnd());
		}

		dmpOptLogMapper.delete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#deleteById(com.ycxc.vmts.controller.
	 * bean.DmpOptLogRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDelete(DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpOptLogRequest.getOptId() != null) {
			param.put("optId", dmpOptLogRequest.getOptId());
		}
		//操作人ID
		if (dmpOptLogRequest.getUserId() != null) {
			param.put("userId", dmpOptLogRequest.getUserId());
		}
		//操作人姓名
		if (!StringUtils.isEmpty(dmpOptLogRequest.getUserName())) {
			param.put("userName", dmpOptLogRequest.getUserName());
		}
		//操作时间起
		if (dmpOptLogRequest.getOptTimeStart() != null) {
			param.put("optTimeStart", dmpOptLogRequest.getOptTimeStart());
		}
		//操作时间止
		if (dmpOptLogRequest.getOptTimeEnd() != null) {
			param.put("optTimeEnd", dmpOptLogRequest.getOptTimeEnd());
		}
		//操作功能模块
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptModular())) {
			param.put("optModular", dmpOptLogRequest.getOptModular());
		}
		//操作类型
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptType())) {
			param.put("optType", dmpOptLogRequest.getOptType());
		}
		//操作描述
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptDesc())) {
			param.put("optDesc", dmpOptLogRequest.getOptDesc());
		}
		//操作方法
		if (!StringUtils.isEmpty(dmpOptLogRequest.getMethod())) {
			param.put("method", dmpOptLogRequest.getMethod());
		}
		//请求参数
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRequestParam())) {
			param.put("requestParam", dmpOptLogRequest.getRequestParam());
		}
		//操作结果
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptResult())) {
			param.put("optResult", dmpOptLogRequest.getOptResult());
		}
		//IP地址
		if (!StringUtils.isEmpty(dmpOptLogRequest.getOptIp())) {
			param.put("optIp", dmpOptLogRequest.getOptIp());
		}
		//备注
		if (!StringUtils.isEmpty(dmpOptLogRequest.getRemark())) {
			param.put("remark", dmpOptLogRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpOptLogRequest.getDataStatus())) {
			param.put("dataStatus", dmpOptLogRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpOptLogRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpOptLogRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpOptLogRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpOptLogRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpOptLogRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpOptLogRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpOptLogRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpOptLogRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpOptLogRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpOptLogRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpOptLogRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpOptLogRequest.getUpdateTimeEnd());
		}

		dmpOptLogMapper.softDelete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpOptLogService#addBatch(com.ycxc.vmts.controller.
	 * bean.DmpOptLogVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpOptLogBatch> addBatch(DmpOptLogBatch dmpOptLogBatch, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpOptLogBatch> baseBeanResponse = new BaseBeanResponse<>();

		List<DmpOptLog> dmpOptLogs = dmpOptLogBatch.getDmpOptLogs();

		if (CollectionUtils.isEmpty(dmpOptLogs)) {
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}

		dmpOptLogs = dmpOptLogs.stream().map(dmpOptLog -> {
			/*$*setOptIdCodeReplace*$*/
			// 创建人
			try {
				dmpOptLog.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			// 创建时间
			dmpOptLog.setCreateTime(new Date());

			return dmpOptLog;
		}).collect(Collectors.toList());

		dmpOptLogMapper.insertBatch(dmpOptLogs);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpOptLogBatch);

		return baseBeanResponse;
	}

	/**
	 *批量删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpOptLogMapper.deleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/**
	 *批量软删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse softDeleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpOptLogMapper.softDeleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}
	
	

}
